@@ -24,7 +24,6 @@
 #include <unistd.h>
 #else
 #include <kpluginfactory.h>
-#include <kpluginloader.h>
 #endif
 
 static inline KAboutData aboutData()
@@ -60,9 +59,6 @@ int main(int argc, char **argv)
     QGuiApplication::setDesktopSettingsAware(false);
     QGuiApplication a(argc, argv);
     KAboutData::setApplicationData(aboutData());
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setFallbackSessionManagementEnabled(false);
-#endif
     auto disableSessionManagement = [](QSessionManager &sm) {
         sm.setRestartHint(QSessionManager::RestartNever);
     };
@@ -155,3 +151,5 @@ void KWrited::block_in()
 #if !BUILD_AS_EXECUTABLE
 #include "kwrited.moc"
 #endif
+
+#include "moc_kwrited.cpp"
